==> symfony_5.4.4+dfsg.orig.tar.xz: symfony-5.4.4/src/Symfony/Component/Intl/Resources/data/scripts/ks.php <==
<?php

return [
    'Names' => [
        'Arab' => 'اَربی',
        'Aran' => 'نستعلیق',
        'Armn' => 'اَرمانیَن',
        'Avst' => 'اَویستَن',
        'Bali' => 'بالَنیٖز',
        'Batk' => 'باتَک',
        'Beng' => 'بینگٲلۍ',
        'Blis' => 'بِلِس سِمبلز',
        'Bopo' => 'بوپوموفو',
        'Brah' => 'براہمی',
        'Brai' => 'بریل',
        'Bugi' => 'بُگِنیٖز',
        'Buhd' => 'بُہِد',
        'Cans' => 'یُنِفایِڑ کنیڑِیَن ایب آرجِنَل سِلیبِک',
        'Cari' => 'کاریَن',
        'Cham' => 'چَم',
        'Cher' => 'چیروکی',
        'Cirt' => 'کِرتھ',
        'Copt' => 'کاپٹِک',
        'Cprt' => 'کِپرایِٹ',
        'Cyrl' => 'سَیرِلِک',
        'Cyrs' => 'پرون چٔرچسلیوونِک سَیرِلِک',
        'Deva' => 'دیوناگری',
        'Dsrt' => 'ڈیسٔریٹ',
        'Egyd' => 'اِجپشِیَن ڈِماٹِک',
        'Egyh' => 'اِجِپشَن ہَیریٹِک',
        'Egyp' => 'اِجِپشَن ہَیروگلِپھس',
        'Ethi' => 'اِتھیوپِک',
        'Geok' => 'جارجِیَن کھتسوری',
        'Geor' => 'جارجِیَن',
        'Glag' => 'گلیگولِٹِک',
        'Goth' => 'گوتھِک',
        'Grek' => 'گرَنتھا',
        'Gujr' => 'گریٖک',
        'Guru' => 'گُجرٲتۍ',
        'Hang' => 'ہانگُل',
        'Hani' => 'ہان',
        'Hano' => 'ہانُنوٗ',
        'Hans' => 'سِمپلِفایِڑ ہان',
        'Hant' => 'ٹریڑِشَنَل',
        'Hebr' => 'ہِبرِو',
        'Hira' => 'ہیٖراگانا',
        'Hmng' => 'پَہاو مانگ',
        'Hrkt' => 'کَٹاکانا یا ہِراگانا',
        'Hung' => 'پرون ہَنگیریَن',
        'Inds' => 'اِنڈَس',
        'Ital' => 'اولڈ اِٹیلِک',
        'Java' => 'جاوَنیٖز',
        'Jpan' => 'جیپَنیٖز',
        'Kali' => 'کایا لی',
        'Kana' => 'کَتاکانا',
        'Khar' => 'خَروشتھی',
        'Khmr' => 'کھٕمیر',
        'Knda' => 'کَنَڑا',
        'Kore' => 'کوریَن',
        'Lana' => 'لانا',
        'Laoo' => 'لاو',
        'Latf' => 'فرکتُر لیٹِن',
        'Latg' => 'گیلِک لیٹَن',
        'Latn' => 'لیٹِن',
        'Lepc' => 'لیپکا',
        'Limb' => 'لِمبوٗ',
        'Lina' => 'لیٖنیَر اے',
        'Linb' => 'لیٖنیَر بی',
        'Lyci' => 'لیسِیَن',
        'Lydi' => 'لیدِیَن',
        'Mand' => 'مَندییَن',
        'Mani' => 'مانیشییَن',
        'Maya' => 'مایَن ہیٖروگلِپھ',
        'Mero' => 'مِرایٹِک',
        'Mlym' => 'مَلیالَم',
        'Mong' => 'مَنگولیَن',
        'Moon' => 'موٗن',
        'Mtei' => 'میتی مایَک',
        'Mymr' => 'مَیَنمار',
        'Nkoo' => 'این کو',
        'Ogam' => 'اوگہام',
        'Olck' => 'اول چِکی',
        'Orkh' => 'اورکھون',
        'Orya' => 'اورِیا',
        'Osma' => 'اوسمانیا',
        'Perm' => 'اولڈ پٔرمِک',
        'Phag' => 'پھاگس پا',
        'Phlv' => 'بوٗک پَہَلوی',
        'Phnx' => 'پھونِشِیَن',
        'Plrd' => 'پولاڑ پھونِٹِک',
        'Rjng' => 'ریجَنگ',
        'Roro' => 'رونگو رونگو',
        'Runr' => 'رَنِک',
        'Samr' => 'سَمارِٹَن',
        'Sara' => 'سَراتی',
        'Saur' => 'سوراشٹرا',
        'Sgnw' => 'اِشارٲتی لِکھٲے',
        'Shaw' => 'شاویَن',
        'Sinh' => 'سِنہالا',
        'Sund' => 'سَنڈَنیٖز',
        'Sylo' => 'سیلوتی ناگری',
        'Syrc' => 'سیٖرِیَک',
        'Syre' => 'ایسٹرینجِلو سیٖرِیَک',
        'Syrj' => 'مغرِبی سیٖریَک',
        'Syrn' => 'مشرَقی سیٖریَک',
        'Tagb' => 'تَگبَنوا',
        'Tale' => 'تَیلیے',
        'Talu' => 'نۆو تیلو',
        'Taml' => 'تَمِل',
        'Telu' => 'تیلگوٗ',
        'Teng' => 'تینگوار',
        'Tfng' => 'تِفِناگ',
        'Tglg' => 'تَگَلوگ',
        'Thaa' => 'تھانا',
        'Thai' => 'تھاے',
        'Tibt' => 'تِبتی',
        'Ugar' => 'اُگارِٹِک',
        'Vaii' => 'واے',
        'Visp' => 'وِزِبٕل سپیٖچ',
        'Xpeo' => 'پرون فارسی',
        'Xsux' => 'سُمیرو اکادیَن کوٗنِفام',
        'Yiii' => 'یٖی',
        'Zxxx' => 'لیکھنَے',
        'Zyyy' => 'عام',
    ],
];

==> symfony_7.4.0~rc2+dfsg.orig.tar.xz: symfony-7.4.0~rc2/src/Symfony/Component/Intl/Resources/data/scripts/ks.php <==
<?php

return [
    'Names' => [
        'Arab' => 'عربی',
        'Aran' => 'نستعلیق',
        'Armn' => 'اَرمانیَن',
        'Avst' => 'اَویستَن',
        'Bali' => 'بالَنیٖز',
        'Batk' => 'باتَک',
        'Beng' => 'بینگٲلؠ',
        'Blis' => 'بِلِس سِمبلز',
        'Bopo' => 'بوپوموفو',
        'Brah' => 'براہمی',
        'Brai' => 'بریل',
        'Bugi' => 'بُگِنیٖز',
        'Buhd' => 'بُہِد',
        'Cans' => 'یُنِفایِڑ کنیڑِیَن ایب آرجِنَل سِلیبِک',
        'Cari' => 'کاریَن',
        'Cham' => 'چَم',
        'Cher' => 'چیروکی',
        'Cirt' => 'کِرتھ',
        'Copt' => 'کاپٹِک',
        'Cprt' => 'کِپرایِٹ',
        'Cyrl' => 'سَیرِلِک',
        'Cyrs' => 'پرون چٔرچسلیوونِک سَیرِلِک',
        'Deva' => 'دیوناگری',
        'Dsrt' => 'ڈیسٔریٹ',
        'Egyd' => 'اِجپشِیَن ڈِماٹِک',
        'Egyh' => 'اِجِپشَن ہَیریٹِک',
        'Egyp' => 'اِجِپشَن ہَیروگلِپھس',
        'Ethi' => 'اِتھیوپِک',
        'Geok' => 'جارجِیَن کھتسوری',
        'Geor' => 'جارجِیَن',
        'Glag' => 'گلیگولِٹِک',
        'Goth' => 'گوتھِک',
        'Grek' => 'گرَنتھا',
        'Gujr' => 'گریٖک',
        'Guru' => 'گُجرٲتؠ',
        'Hang' => 'ہانگُل',
        'Hani' => 'ہان',
        'Hano' => 'ہانُنوٗ',
        'Hans' => 'سَہل ﴿ترجمع اِشارٕ: یِم ورژن رَسم الخط ہُک ناؤ چھُ چیٖنی باپتھ زَبانٕ ناؤ کِس مجموعَس سٕتؠ اِستعمال یِوان کرنٕہ۔﴾',
        'Hant' => 'رِوٲجی ﴿ترجمع اِشارٕ: یِم ورژن رَسم الخط ہُک ناؤ چھُ چیٖنی باپتھ زَبانٕ ناؤ کِس مجموعَس سٕتؠ اِستعمال یِوان کرنٕہ۔﴾',
        'Hebr' => 'ہِبرِو',
        'Hira' => 'ہیٖراگانا',
        'Hmng' => 'پَہاو مانگ',
        'Hrkt' => 'کَٹاکانا یا ہِراگانا',
        'Hung' => 'پرون ہَنگیریَن',
        'Inds' => 'اِنڈَس',
        'Ital' => 'اولڈ اِٹیلِک',
        'Java' => 'جاوَنیٖز',
        'Jpan' => 'جاپٲنی',
        'Kali' => 'کایا لی',
        'Kana' => 'کَتاکانا',
        'Khar' => 'خَروشتھی',
        'Khmr' => 'کھٕمیر',
        'Knda' => 'کَنَڑا',
        'Kore' => 'کوریَن',
        'Lana' => 'لانا',
        'Laoo' => 'لاو',
        'Latf' => 'فرکتُر لیٹِن',
        'Latg' => 'گیلِک لیٹَن',
        'Latn' => 'لاطیٖنی',
        'Lepc' => 'لیپکا',
        'Limb' => 'لِمبوٗ',
        'Lina' => 'لیٖنیَر اے',
        'Linb' => 'لیٖنیَر بی',
        'Lyci' => 'لیسِیَن',
        'Lydi' => 'لیدِیَن',
        'Mand' => 'مَندییَن',
        'Mani' => 'مانیشییَن',
        'Maya' => 'مایَن ہیٖروگلِپھ',
        'Mero' => 'مِرایٹِک',
        'Mlym' => 'مَلیالَم',
        'Mong' => 'مَنگولیَن',
        'Moon' => 'موٗن',
        'Mtei' => 'میتی مایَک',
        'Mymr' => 'مَیَنمار',
        'Nkoo' => 'این کو',
        'Ogam' => 'اوگہام',
        'Olck' => 'اول چِکی',
        'Orkh' => 'اورکھون',
        'Orya' => 'اورِیا',
        'Osma' => 'اوسمانیا',
        'Perm' => 'اولڈ پٔرمِک',
        'Phag' => 'پھاگس پا',
        'Phlv' => 'بوٗک پَہَلوی',
        'Phnx' => 'پھونِشِیَن',
        'Plrd' => 'پولاڑ پھونِٹِک',
        'Rjng' => 'ریجَنگ',
        'Roro' => 'رونگو رونگو',
        'Runr' => 'رَنِک',
        'Samr' => 'سَمارِٹَن',
        'Sara' => 'سَراتی',
        'Saur' => 'سوراشٹرا',
        'Sgnw' => 'اِشارٲتی لِکھٲے',
        'Shaw' => 'شاویَن',
        'Sinh' => 'سِنہالا',
        'Sund' => 'سَنڈَنیٖز',
        'Sylo' => 'سیلوتی ناگری',
        'Syrc' => 'سیٖرِیَک',
        'Syre' => 'ایسٹرینجِلو سیٖرِیَک',
        'Syrj' => 'مغرِبی سیٖریَک',
        'Syrn' => 'مشرَقی سیٖریَک',
        'Tagb' => 'تَگبَنوا',
        'Tale' => 'تَیلیے',
        'Talu' => 'نۆو تیلو',
        'Taml' => 'تَمِل',
        'Telu' => 'تیلگوٗ',
        'Teng' => 'تینگوار',
        'Tfng' => 'تِفِناگ',
        'Tglg' => 'تَگَلوگ',
        'Thaa' => 'تھانا',
        'Thai' => 'تھاے',
        'Tibt' => 'تِبتی',
        'Ugar' => 'اُگارِٹِک',
        'Vaii' => 'واے',
        'Visp' => 'وِزِبٕل سپیٖچ',
        'Xpeo' => 'پرون فارسی',
        'Xsux' => 'سُمیرو اکادیَن کوٗنِفام',
        'Yiii' => 'یٖی',
        'Zxxx' => 'لیکھنَے',
        'Zyyy' => 'عام',
    ],
];
